issuers

package
v0.0.0-...-4166da5 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 13, 2026 License: Apache-2.0 Imports: 16 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type SSHIssuer

type SSHIssuer struct {
	// contains filtered or unexported fields
}

SSHIssuer implements the cert.Issuer interface for SSH certificates.

func NewSSHIssuer

func NewSSHIssuer(config SSHIssuerConfig) (*SSHIssuer, error)

NewSSHIssuer creates a new instance of SSHIssuer using a config struct.

func (SSHIssuer) Issue

func (sshIssuer SSHIssuer) Issue(_ context.Context) (*ssh.Certificate, error)

Issue implements the cert.Issuer interface method that generates and returns a signed SSH certificate.

type SSHIssuerConfig

type SSHIssuerConfig struct {
	CASigner        ssh.Signer
	CertType        uint32
	KeyID           string
	ValidPrincipals []string
	ValidDuration   time.Duration
	CertSigner      crypto.Signer
	CertDir         string
}

SSHIssuerConfig contains all configuration parameters for SSHIssuer.

type TLSIssuer

type TLSIssuer struct {
	// contains filtered or unexported fields
}

TLSIssuer implements the cert.Issuer interface for TLS certificates.

func NewTLSIssuer

func NewTLSIssuer(config TLSIssuerConfig) (*TLSIssuer, error)

NewTLSIssuer creates a new instance of TLSIssuer using a config struct.

func (TLSIssuer) Issue

func (tlsIssuer TLSIssuer) Issue(_ context.Context) (*tls.Certificate, error)

Issue implements the cert.Issuer interface method that generates and returns a signed TLS certificate.

type TLSIssuerConfig

type TLSIssuerConfig struct {
	CACert       *x509.Certificate
	CASigner     crypto.Signer
	CertTemplate *x509.Certificate
	CertSigner   crypto.Signer
	CertDir      string
	OSKeychain   bool
}

TLSIssuerConfig contains all configuration parameters for TLSIssuer.

Jump to